Learn R Programming

epanetReader (version 1.0.0)

read.msxrpt: Read msx results

Description

reads an Epanet-msx .rpt file into R

Usage

read.msxrpt(file)

Value

Returns an epanetmsx.rpt S3 object .

nodeResults

data.frame

linkResults

data.frame

Arguments

file

the name of the file to read

Details

Specify the needed outputs from an Epanet-msx simulation in the [REPORT] section of the .msx file to create reports for reading with with this function.

The function returns an S3 object (list) with a data.frame for node results and data.frame for link results. These data.frames contain results from all the time periods to facilitate time series plots.

References

Shang, F., Uber, J.G., Rossman, L.A. (2011) EPANET Multi-species Extension User's Manual. US Environmental Protection Agency, Cincinnati.

Examples

Run this code
# path to example file included with this package
msr <- file.path( find.package("epanetReader"), "extdata","example.rpt") 

#read the results into R
x <- read.msxrpt(msr)
names(x)
summary(x)
plot(x)

Run the code above in your browser using DataLab