Learn R Programming

epanetReader (version 1.0.0)

summary.epanet.inp: Summary Method for epanet.inp

Description

Summarizes the network by printing the Title of the network and the number of each type of elements.

Usage

# S3 method for epanet.inp
summary(object, ...)

Arguments

object

of class epanet.inp

...

futher arguments